pub trait AccessibilityModifiers: Modifiable {
Show 13 methods
// Provided methods
fn role(self, role: Role) -> Self { ... }
fn name<U: ToStringLocalized>(self, name: impl Res<U>) -> Self { ... }
fn labeled_by(self, id: impl Into<String>) -> Self { ... }
fn described_by(self, id: impl Into<String>) -> Self { ... }
fn controls(self, id: impl Into<String>) -> Self { ... }
fn active_descendant<U: Into<String> + Clone + 'static>(
self,
id: impl Res<U> + 'static,
) -> Self { ... }
fn live(self, live: Live) -> Self { ... }
fn hidden<U: Into<bool>>(self, hidden: impl Res<U>) -> Self { ... }
fn expanded<U: Into<bool>>(self, expanded: impl Res<U>) -> Self { ... }
fn selected<U: Into<bool>>(self, selected: impl Res<U>) -> Self { ... }
fn orientation<U: Into<Orientation>>(self, orientation: impl Res<U>) -> Self { ... }
fn numeric_value<U: Into<f64>>(self, value: impl Res<U>) -> Self { ... }
fn text_value<U: ToStringLocalized>(self, value: impl Res<U>) -> Self { ... }
}Expand description
Modifiers for changing the accessibility properties of a view.
Provided Methods
Sourcefn name<U: ToStringLocalized>(self, name: impl Res<U>) -> Self
fn name<U: ToStringLocalized>(self, name: impl Res<U>) -> Self
Sets the accessibility name of the view.
Sourcefn labeled_by(self, id: impl Into<String>) -> Self
fn labeled_by(self, id: impl Into<String>) -> Self
Sets the accessibility label relationship for the view using the ID of another view.
Sourcefn described_by(self, id: impl Into<String>) -> Self
fn described_by(self, id: impl Into<String>) -> Self
Sets the accessibility description relationship for the view using the ID of another view.
Sourcefn controls(self, id: impl Into<String>) -> Self
fn controls(self, id: impl Into<String>) -> Self
Sets the accessibility controls relationship for the view using the ID of another view.
Sourcefn active_descendant<U: Into<String> + Clone + 'static>(
self,
id: impl Res<U> + 'static,
) -> Self
fn active_descendant<U: Into<String> + Clone + 'static>( self, id: impl Res<U> + 'static, ) -> Self
Sets the accessibility active descendant relationship for the view.
Sourcefn live(self, live: Live) -> Self
fn live(self, live: Live) -> Self
Sets whether the view should act as an accessibility live region.
Sets whether the view should be hidden from accessibility.
Sourcefn expanded<U: Into<bool>>(self, expanded: impl Res<U>) -> Self
fn expanded<U: Into<bool>>(self, expanded: impl Res<U>) -> Self
Sets whether the view should be announced as expanded (true) or collapsed (false).
Sourcefn selected<U: Into<bool>>(self, selected: impl Res<U>) -> Self
fn selected<U: Into<bool>>(self, selected: impl Res<U>) -> Self
Sets whether the view should be announced as selected (true) or not selected (false).
Sourcefn orientation<U: Into<Orientation>>(self, orientation: impl Res<U>) -> Self
fn orientation<U: Into<Orientation>>(self, orientation: impl Res<U>) -> Self
Sets the accessibility orientation of the view. This does not affect the layout of the view, but is used to inform assistive technologies of the orientation of the view.
Sourcefn numeric_value<U: Into<f64>>(self, value: impl Res<U>) -> Self
fn numeric_value<U: Into<f64>>(self, value: impl Res<U>) -> Self
Sets the accessibility numeric value for the view.
Sourcefn text_value<U: ToStringLocalized>(self, value: impl Res<U>) -> Self
fn text_value<U: ToStringLocalized>(self, value: impl Res<U>) -> Self
Sets the accessibility text value for the view.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.